// CkMht.h: interface for the CkMht class.
//
//////////////////////////////////////////////////////////////////////

#ifndef _CKMHT_H
#define _CKMHT_H

#pragma once

class CkMime;
class CkEmail;
class CkString;

/*
    IMPORTANT: Objects returned by methods as non-const pointers must be deleted
    by the calling application. 

  */

#include "CkObject.h"

// CLASS: CkMht
class CkMht  : public CkObject
{
    private:
	void *m_impl;
	bool m_utf8;	// If true, all input "const char *" parameters are utf-8, otherwise they are ANSI strings.

	// Don't allow assignment or copying these objects.
	CkMht(const CkMht &) { } 
	CkMht &operator=(const CkMht &) { return *this; }

    public:
	void *getImpl(void) { return m_impl; } 

	CkMht(void *impl) : m_impl(impl) { }

	CkMht();
	virtual ~CkMht();

	// BEGIN PUBLIC INTERFACE
	bool get_Utf8(void) const;
	void put_Utf8(bool b);


	bool UnpackMHT(const char *mhtFilename, const char *unpackDir, const char *htmlFilename, const char *partsSubDir);
	bool UnpackMHTString(const char *mhtContents, const char *unpackDir, const char *htmlFilename, const char *partsSubDir);
	bool GetAndZipMHT(const char *url, const char *zipEntryFilename, const char *zipFilename);
	bool GetAndZipEML(const char *url, const char *zipEntryFilename, const char *zipFilename);
	CkEmail *GetEmail(const char *url);
	bool GetAndSaveMHT(const char *url, const char *mhtFilename);
	bool GetAndSaveEML(const char *url, const char *emlFilename);
	bool GetMHT(const char *url, CkString &mht);
	bool GetEML(const char *url, CkString &eml);

	CkEmail *HtmlToEmail(const char *htmlText);

	bool HtmlToMHT(const char *htmlText, CkString &mht);
	bool HtmlToEML(const char *htmlText, CkString &eml);

	bool UnlockComponent(const char *unlockCode);
	bool IsUnlocked(void) const;

	void AddExternalStyleSheet(const char *url);
	void ExcludeImagesMatching(const char *pattern);
	void RestoreDefaults();

        // When rendering MHT, this flag determines what is done when the
        // HTML offers a <noscript> alternative.  The default is to include
        // both <script> and <noscript> tags.
        // If this setting is false, then the scripts (<script>...</script>)
        // are removed and the <noscript> tags are removed.
	bool get_PreferMHTScripts(void);
	void put_PreferMHTScripts(bool newVal);

	bool get_NoScripts(void);
	void put_NoScripts(bool newVal);

	bool get_EmbedImages(void);
	void put_EmbedImages(bool newVal);

	bool get_DebugTagCleaning(void);
	void put_DebugTagCleaning(bool newVal);

	void get_WebSiteLogin(CkString &str);
	void put_WebSiteLogin(const char *newVal);

	void get_WebSitePassword(CkString &str);
	void put_WebSitePassword(const char *newVal);

	void get_DebugHtmlBefore(CkString &str);
	void put_DebugHtmlBefore(const char *newVal);

	void get_DebugHtmlAfter(CkString &str);
	void put_DebugHtmlAfter(const char *newVal);

	void get_BaseUrl(CkString &str);
	void put_BaseUrl(const char *newVal);

	void get_Proxy(CkString &str);
	void put_Proxy(const char *newVal);

	void get_Version(CkString &str);

	// Timeouts are in seconds
	long get_ReadTimeout(void);
	void put_ReadTimeout(long newVal);

	// Timeouts are in seconds
	long get_ConnectTimeout(void);
	void put_ConnectTimeout(long newVal);

	// Error log retrieval and saving (these methods are common to all Chilkat VC++ classes.)
	bool SaveLastError(const char *filename);
        void LastErrorXml(CkString &str);
        void LastErrorHtml(CkString &str);
        void LastErrorText(CkString &str);

	// END PUBLIC INTERFACE


};


#endif


